from illallangi.rdf.adapters.aviation import AviationAdapter
from illallangi.rdf.adapters.education import EducationAdapter
from illallangi.rdf.adapters.residential import ResidentialAdapter

__all__ = [
    "AviationAdapter",
    "EducationAdapter",
    "ResidentialAdapter",
]
