from illallangi.rdf.models.airline import Airline
from illallangi.rdf.models.airport import Airport
from illallangi.rdf.models.course import Course
from illallangi.rdf.models.residence import Residence

__all__ = [
    "Airline",
    "Airport",
    "Course",
    "Residence",
]
